"""Common summary functions/statistics"""

import numpy as np  # pyright: ignore[reportMissingImports]

count = len
mean = np.mean
sum = np.sum
max = np.max
median = np.median
min = np.min
std = np.std
